{# Extend Furo's base layout to add custom favicon links #}
{% extends "!layout.html" %}

{% block extrahead %}
  {{ super() }}
  {# Favicons for various platforms #}
  <link rel="apple-touch-icon" sizes="180x180" href="{{ pathto('_static/apple-touch-icon.png', 1) }}">
  <link rel="icon" type="image/png" sizes="32x32" href="{{ pathto('_static/favicon-32x32.png', 1) }}">
  <link rel="icon" type="image/png" sizes="16x16" href="{{ pathto('_static/favicon-16x16.png', 1) }}">
  <link rel="icon" type="image/png" sizes="192x192" href="{{ pathto('_static/android-chrome-192x192.png', 1) }}">
  <link rel="icon" type="image/png" sizes="512x512" href="{{ pathto('_static/android-chrome-512x512.png', 1) }}">
{% endblock %}
