<a class="sidebar-brand" href="{{ pathto(master_doc) }}">
    <div class="sidebar-brand-container">
      <img class="sidebar-logo" src="{{ pathto('_static/logo.png', 1) }}" alt="Logo"/>
      <div class="sidebar-brand-text">Lynx</div>
    </div>
  </a>